@@ -40,9 +40,11 @@ define([
                 // classification
                 confusion_matrix: true, report: true, 
                 accuracy: false, precision: false, recall: false, f1_score: false,
-                roc_curve: false, auc: false,
                 // clustering
-                silhouetteScore: true, ari: false, nm: false,
+                clusteredIndex: 'clusters',
+                silhouetteScore: true, ari: false, nmi: false,
+                featureData2: 'X',
+                targetData2: 'y',
                 ...this.state
             }
         }
@@ -62,26 +64,47 @@ define([
                 let modelType = $(this).val();
                 that.state.modelType = modelType;
 
+                $(that.wrapSelector('.vp-upper-box')).hide();
+                $(that.wrapSelector('.vp-upper-box.' + modelType)).show();
+
                 $(that.wrapSelector('.vp-eval-box')).hide();
                 $(that.wrapSelector('.vp-eval-'+modelType)).show();  
 
-                if (modelType == 'clf') {
+                if (modelType == 'rgs') {
+                    // Regression
+
+                } else if (modelType == 'clf') {
                     // Classification - model selection
-                    if (that.checkToShowModel() == true) {
-                        $(that.wrapSelector('.vp-ev-model')).show();
+                    // if (that.checkToShowSelector('roc-auc') == true) {
+                    //     $(that.wrapSelector('.vp-ev-model.roc-auc')).prop('disabled', false);
+                    // } else {
+                    //     $(that.wrapSelector('.vp-ev-model.roc-auc')).prop('disabled', true);
+                    // }
+                } else {
+                    // Clustering
+                    if (that.checkToShowSelector('silhouette') == true) {
+                        $(that.wrapSelector('.vp-ev-model.silhouette')).prop('disabled', false);
+                    } else {
+                        $(that.wrapSelector('.vp-ev-model.silhouette')).prop('disabled', true);
+                    }
+                    if (that.checkToShowSelector('ari-nmi') == true) {
+                        $(that.wrapSelector('.vp-ev-model.ari-nmi')).prop('disabled', false);
+                    } else {
+                        $(that.wrapSelector('.vp-ev-model.ari-nmi')).prop('disabled', true);
                     }
                 }
             });
 
-            // open model selection show
+            // check to enable/disable selector
             $(this.wrapSelector('.vp-eval-check')).on('change', function() {
                 let checked = $(this).prop('checked');
+                let type = $(this).data('type');
 
                 if (checked) {
-                    $(that.wrapSelector('.vp-ev-model')).show();
+                    $(that.wrapSelector('.vp-ev-model.' + type)).prop('disabled', false);
                 } else {
-                    if (that.checkToShowModel() == false) {
-                        $(that.wrapSelector('.vp-ev-model')).hide();
+                    if (that.checkToShowSelector(type) == false) {
+                        $(that.wrapSelector('.vp-ev-model.' + type)).prop('disabled', true);
                     }
                 }
             });
@@ -91,8 +114,8 @@ define([
          * Check if anything checked available ( > 0)
          * @returns 
          */
-        checkToShowModel() {
-            let checked = $(this.wrapSelector('.vp-eval-check:checked')).length;
+        checkToShowSelector(type) {
+            let checked = $(this.wrapSelector('.vp-eval-check[data-type="' + type + '"]:checked')).length;
             if (checked > 0) { 
                 return true;
             }
@@ -106,39 +129,36 @@ define([
             $(page).find('.vp-eval-'+this.state.modelType).show();
 
             // varselector
-            let varSelector = new VarSelector2(this.wrapSelector(), ['DataFrame', 'list', 'str']);
+            let varSelector = new VarSelector2(this.wrapSelector());
             varSelector.setComponentID('predictData');
             varSelector.addClass('vp-state vp-input');
             varSelector.setValue(this.state.predictData);
             $(page).find('#predictData').replaceWith(varSelector.toTagString());
 
-            varSelector = new VarSelector2(this.wrapSelector(), ['DataFrame', 'list', 'str']);
+            varSelector = new VarSelector2(this.wrapSelector());
             varSelector.setComponentID('targetData');
             varSelector.addClass('vp-state vp-input');
             varSelector.setValue(this.state.targetData);
             $(page).find('#targetData').replaceWith(varSelector.toTagString());
 
-            // model
-            // set model list
-            let modelOptionTag = new com_String();
-            vpKernel.getModelList('Classification').then(function(resultObj) {
-                let { result } = resultObj;
-                var modelList = JSON.parse(result);
-                modelList && modelList.forEach(model => {
-                    let selectFlag = '';
-                    if (model.varName == that.state.model) {
-                        selectFlag = 'selected';
-                    }
-                    modelOptionTag.appendFormatLine('<option value="{0}" data-type="{1}" {2}>{3} ({4})</option>', 
-                        model.varName, model.varType, selectFlag, model.varName, model.varType);
-                });
-                $(page).find('#model').html(modelOptionTag.toString());
-                $(that.wrapSelector('#model')).html(modelOptionTag.toString());
+            // Clustering - data selection
+            varSelector = new VarSelector2(this.wrapSelector());
+            varSelector.setComponentID('clusteredIndex');
+            varSelector.addClass('vp-state vp-input');
+            varSelector.setValue(this.state.clusteredIndex);
+            $(page).find('#clusteredIndex').replaceWith(varSelector.toTagString());
 
-                if (!that.state.model || that.state.model == '') {
-                    that.state.model = $(that.wrapSelector('#model')).val();
-                }
-            });
+            varSelector = new VarSelector2(this.wrapSelector());
+            varSelector.setComponentID('featureData2');
+            varSelector.addClass('vp-state vp-input vp-ev-model silhouette');
+            varSelector.setValue(this.state.featureData2);
+            $(page).find('#featureData2').replaceWith(varSelector.toTagString());
+
+            varSelector = new VarSelector2(this.wrapSelector());
+            varSelector.setComponentID('targetData2');
+            varSelector.addClass('vp-state vp-input vp-ev-model ari-nmi');
+            varSelector.setValue(this.state.targetData2);
+            $(page).find('#targetData2').replaceWith(varSelector.toTagString());
 
             // load state
             let that = this;
@@ -169,35 +189,48 @@ define([
                 }
             });
 
-            if (this.state.modelType == 'clf') {
-                if (this.state.roc_curve == true || this.state.auc == true) {
-                    $(page).find('.vp-ev-model').show();
-                } else {
-                    $(page).find('.vp-ev-model').hide();
-                }
+            $(page).find('.vp-upper-box').hide();
+            $(page).find('.vp-upper-box.' + this.state.modelType).show();
+
+            if (this.state.modelType == 'rgs') {
+                // Regression
+
+            } else if (this.state.modelType == 'clf') {
+                // Classification
+                // if (this.state.roc_curve == false && this.state.auc == false) {
+                //     $(page).find('.vp-ev-model.roc-auc').prop('disabled', true);
+                // }
             } else {
-                $(page).find('.vp-ev-model').hide();
+                // Clustering
+                if (this.state.silhouetteScore == false) {
+                    $(page).find('.vp-ev-model.silhouette').prop('disabled', true);
+                }
+                if (this.state.ari == false && this.state.nmi == false) {
+                    $(page).find('.vp-ev-model.ari-nmi').prop('disabled', true);
+                }
             }
 
             return page;
         }
         
         generateImportCode() {
-            return 'from sklearn import metrics';
+            return ['from sklearn import metrics'];
         }
 
         generateCode() {
-            let codeCells = [];
+            let codeCells = [
+                ...this.generateImportCode() // run import codes
+            ];
             let code = new com_String();
             let { 
                 modelType, predictData, targetData,
                 // classification
-                confusion_matrix, report, accuracy, precision, recall, f1_score, roc_curve, auc,
-                model,
+                confusion_matrix, report, accuracy, precision, recall, f1_score, 
                 // regression
                 coefficient, intercept, r_squared, mae, mape, rmse, scatter_plot,
                 // clustering
-                sizeOfClusters, silhouetteScore, ari, nm
+                sizeOfClusters, silhouetteScore, ari, nmi,
+                clusteredIndex, featureData2, targetData2
             } = this.state;
 
             //====================================================================
@@ -240,21 +273,21 @@ define([
                     code.appendFormat("metrics.f1_score({0}, {1}, average='weighted')", targetData, predictData);
                     codeCells.push(code.toString());
                 }
-                if (roc_curve) {
-                    code = new com_String();
-                    code.appendLine("# ROC Curve");
-                    code.appendFormatLine("fpr, tpr, thresholds = metrics.roc_curve({0}, {1}.decision_function({2}))", predictData, model, targetData);
-                    code.appendLine("plt.plot(fpr, tpr, label='ROC Curve')");
-                    code.appendLine("plt.xlabel('Sensitivity') ");
-                    code.append("plt.ylabel('Specificity') ")
-                    codeCells.push(code.toString());
-                }
-                if (auc) {
-                    code = new com_String();
-                    code.appendLine("# AUC");
-                    code.appendFormat("metrics.roc_auc_score({0}, {1}.decision_function({2}))", predictData, model, targetData);
-                    codeCells.push(code.toString());
-                }
+                // if (roc_curve) {
+                //     code = new com_String();
+                //     code.appendLine("# ROC Curve");
+                //     code.appendFormatLine("fpr, tpr, thresholds = metrics.roc_curve({0}, {1}.decision_function({2}))", predictData, model, targetData);
+                //     code.appendLine("plt.plot(fpr, tpr, label='ROC Curve')");
+                //     code.appendLine("plt.xlabel('Sensitivity') ");
+                //     code.append("plt.ylabel('Specificity') ")
+                //     codeCells.push(code.toString());
+                // }
+                // if (auc) {
+                //     code = new com_String();
+                //     code.appendLine("# AUC");
+                //     code.appendFormat("metrics.roc_auc_score({0}, {1}.decision_function({2}))", predictData, model, targetData);
+                //     codeCells.push(code.toString());
+                // }
             }
 
             //====================================================================
@@ -317,19 +350,19 @@ define([
                 if (silhouetteScore) {
                     code = new com_String();
                     code.appendLine("# Silhouette score");
-                    code.appendFormat("print(f'Silhouette score: {metrics.cluster.silhouette_score({0}, {1})}')", targetData, predictData);
+                    code.appendFormat("print(f'Silhouette score: {metrics.cluster.silhouette_score({0}, {1})}')", featureData2, clusteredIndex);
                     codeCells.push(code.toString());
                 }
                 if (ari) {
                     code = new com_String();
-                    code.appendLine("# ARI");
-                    code.appendFormat("print(f'ARI: {metrics.cluster.adjusted_rand_score({0}, {1})}')", targetData, predictData);
+                    code.appendLine("# ARI(Adjusted Rand score)");
+                    code.appendFormat("print(f'ARI: {metrics.cluster.adjusted_rand_score({0}, {1})}')", targetData2, clusteredIndex);
                     codeCells.push(code.toString());
                 }
-                if (nm) {
+                if (nmi) {
                     code = new com_String();
-                    code.appendLine("# NM");
-                    code.appendFormat("print(f'NM: {metrics.cluster.normalized_mutual_info_score({0}, {1})}')", targetData, predictData);
+                    code.appendLine("# NMI(Normalized Mutual Info Score)");
+                    code.appendFormat("print(f'NM: {metrics.cluster.normalized_mutual_info_score({0}, {1})}')", targetData2, clusteredIndex);
                     codeCells.push(code.toString());
                 }
             }
